@@ -2,7 +2,7 @@ package DateTime::Format::Flexible;
 use strict;
 use warnings;
 
-our $VERSION = '0.23';
+our $VERSION = '0.25';
 
 use base 'DateTime::Format::Builder';
 
@@ -35,6 +35,7 @@ my $XMMXDDYYYY = qr{X(\d{1,2})X${DELIM}?(\d{1,2})${DELIM}?(\d{1,4})};
 
 my $HMSMD = [ qw( hour minute second month day ) ];
 my $HMSMDY = [ qw( hour minute second month day year ) ];
+my $HMSYMD = [ qw( hour minute second year month day ) ];
 my $HMSNSMDY = [ qw( hour minute second nanosecond month day year ) ];
 my $HMSDM = [ qw( hour minute second day month ) ];
 my $HMMDY = [ qw( hour minute month day year ) ];
@@ -136,6 +137,7 @@ my $formats =
 
  { length => 16, params => $YMDHMS, regex => qr{\A(\d{4})(\d{2})(\d{2})(\d{2}):(\d{2}):(\d{2})\z} },
  { length => 13, params => $YMDHM , regex => qr{\A(\d{4})(\d{2})(\d{2})(\d{2}):(\d{2})\z} },
+ { length => 8 , params => $YMD   , regex => qr{\A(\d{4})(\d{2})(\d{2})\z} },
 
  { length => 10 , params => $YMD   , regex => qr{\AY(\d{2})Y$DELIM(\d{2})$DELIM(\d{2})\z} , postprocess => \&_fix_year } ,
  # 96-06-1800:00:00
@@ -217,10 +219,14 @@ my $formats =
  # 5:30:25 12101965
  { length => [14..16], params => $HMSMDY, regex => qr{\A${HMS}${DELIM}${MON}${DAY}${YEAR}\z}, postprocess => \&_fix_year },
  { length => [14..19], params => $HMSMDY, regex => qr{\A${HMS}${DELIM}${MMDDYYYY}\z}, postprocess => \&_fix_year },
+
+ { length => [14..19], params => $HMSYMD, regex => qr{\A${HMS}${DELIM}${YYYYMMDD}\z}, postprocess => \&_fix_year },
+
  # 5:30 pm 121065 => 2065-12-01T17:30:00
  { length => [14,18], params => $HMAPMMDDYYYY, regex => qr{\A${HM}\s${AMPM}\s${MON}${DAY}${YEAR}},postprocess => [\&_fix_ampm, \&_fix_year] },
  { length => [16,19], params => $HMAPMMDDYYYY, regex => qr{\A${HM}\s${AMPM}\s${MMDDYYYY}},postprocess => [\&_fix_ampm, \&_fix_year] },
 
+
  ########################################################
  ##### Alpha months
  # _fix_alpha changes month name to "XMX"
@@ -522,7 +528,7 @@ sub _fix_alpha
         }
     }
 
-    printf( "#-->%s<-- (%s) [%s] \n" , $date , length( $date ) , $p->{time_zone}||q{none} ) if $ENV{DFF_DEBUG};
+    printf( "# date: (%s) length: (%s) timezone: [%s] \n" , $date , length( $date ) , $p->{time_zone}||q{none} ) if $ENV{DFF_DEBUG};
     return $date;
 }
 
@@ -561,6 +567,7 @@ sub _parse_timezone
     # set any trailing string timezones.  they cannot start with a digit
     if ( my ( $tz ) = $date =~ m{.+\s+(\D[^\s]+)\z} )
     {
+        printf( "# possible timezone (%s)\n", $tz) if $ENV{DFF_DEBUG};
         my $orig_tz = $tz;
         if ( exists $extra_args->{tz_map}->{$tz} )
         {
@@ -568,6 +575,7 @@ sub _parse_timezone
         }
         if ( DateTime::TimeZone->is_valid_name( $tz ) )
         {
+            printf( "#  timezone matched\n" ) if $ENV{DFF_DEBUG};
             $date =~ s{\Q$orig_tz\E}{};
             $p->{time_zone} = $tz;
             return ( $date , $p );
@@ -629,11 +637,14 @@ sub _fix_ampm
 
     return if not defined $args{parsed}{ampm};
 
+    printf( "# have ampm [%s]\n", $args{parsed}{ampm} ) if $ENV{DFF_DEBUG};
+
     my $ampm = $args{parsed}{ampm};
     delete $args{parsed}{ampm};
 
     if ( $ampm =~ m{a\.?m?\.?}mix )
     {
+        printf( "#   found am hour=[%s]\n", $args{parsed}{hour} ) if $ENV{DFF_DEBUG};
         if( $args{parsed}{hour} == 12 )
         {
             $args{parsed}{hour} = 0;
@@ -642,6 +653,7 @@ sub _fix_ampm
     }
     elsif ( $ampm =~ m{p\.?m?\.?}mix )
     {
+        printf( "#   found pm hour=[%s]\n", $args{parsed}{hour} ) if $ENV{DFF_DEBUG};
         $args{parsed}{hour} += 12;
         if ( $args{parsed}{hour} == 24 )
         {
@@ -861,8 +873,8 @@ example:
 
 =item * C<MMYY> (optional)
 
-By default, this module parse 12/10 as December 10th of the current
-year (MM/DD).
+By default, this module will parse 12/10 as December 10th of the
+current year (MM/DD).
 
 If you want it to parse this as MM/YY instead, you can enable the
 C<MMYY> option.
